import ClientManager from '../clientManager';
import ChannelManager from '../channelManager';

var expect = require('chai').expect;
var assert = require('chai').assert;

var name: string = 'test channel';
var data: any = { 'channel_type': 'private', 'client_type':'private', 'user_id': 125, 'user_roles': ['broadcaster', 'receiver'], 'channel': name }
var WebSocketClient = require('websocket').client;
var wsClient = new WebSocketClient();
var clientManager = new ClientManager();
var channelManager = new ChannelManager();

describe('ClientManager', function () {
  it('should add a client', function () {
    let result = clientManager.addClient(data, channelManager, wsClient);
    expect(result).to.not.be.null
  });

  it('should get clients of type', function () {
    let result = clientManager.clientsOfType('private');
    assert(result.length > 0, 'returns one client');
  });

  it('should see client exists', function () {
    let exists = clientManager.clientExists(data.user_id);
    let result = exists ? true : false;
    expect(result).to.be.equal(true);
  });

  it('should see client does not exists', function () {
    let exists = clientManager.clientExists(200);
    let result = exists ? true : false;
    expect(result).to.be.equal(false);
  });

  it('should get an existing client', function () {
    let exists = clientManager.getClient(data.user_id);
    let result = exists ? true : false;
    expect(result).to.be.equal(true);
  });

  it('should not get an existing client', function () {
    let exists = clientManager.getClient(200);
    let result = exists ? true : false;
    expect(result).to.be.equal(false);
  });

  it('should add client of type PrivateClient', function () {
    let result = clientManager.getClientType(data, channelManager, wsClient);
    expect(result.type()).to.be.equal('private');
  });
});
